@@ -16,7 +16,7 @@ from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
-from .literals import ConnectionMode, ConnectorType
+from .literals import ConnectionModeType, ConnectorTypeType
 from .type_defs import (
     ConnectorProfileConfigTypeDef,
     CreateConnectorProfileResponseTypeDef,
@@ -64,7 +64,7 @@ class Exceptions:
 
 class AppflowClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -73,21 +73,21 @@ class AppflowClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_connector_profile(
         self,
         connectorProfileName: str,
-        connectorType: ConnectorType,
-        connectionMode: ConnectionMode,
+        connectorType: ConnectorTypeType,
+        connectionMode: ConnectionModeType,
         connectorProfileConfig: ConnectorProfileConfigTypeDef,
         kmsArn: str = None,
     ) -> CreateConnectorProfileResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.create_connector_profile)
-        [Show boto3-stubs documentation](./client.md#create-connector-profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.create_connector_profile)
+        [Show boto3-stubs documentation](./client.md#create_connector_profile)
         """
 
     def create_flow(
@@ -102,67 +102,67 @@ class AppflowClient:
         tags: Dict[str, str] = None,
     ) -> CreateFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.create_flow)
-        [Show boto3-stubs documentation](./client.md#create-flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.create_flow)
+        [Show boto3-stubs documentation](./client.md#create_flow)
         """
 
     def delete_connector_profile(
         self, connectorProfileName: str, forceDelete: bool = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
-        [Show boto3-stubs documentation](./client.md#delete-connector-profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
+        [Show boto3-stubs documentation](./client.md#delete_connector_profile)
         """
 
     def delete_flow(self, flowName: str, forceDelete: bool = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.delete_flow)
-        [Show boto3-stubs documentation](./client.md#delete-flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.delete_flow)
+        [Show boto3-stubs documentation](./client.md#delete_flow)
         """
 
     def describe_connector_entity(
         self,
         connectorEntityName: str,
-        connectorType: ConnectorType = None,
+        connectorType: ConnectorTypeType = None,
         connectorProfileName: str = None,
     ) -> DescribeConnectorEntityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
-        [Show boto3-stubs documentation](./client.md#describe-connector-entity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
+        [Show boto3-stubs documentation](./client.md#describe_connector_entity)
         """
 
     def describe_connector_profiles(
         self,
         connectorProfileNames: List[str] = None,
-        connectorType: ConnectorType = None,
+        connectorType: ConnectorTypeType = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> DescribeConnectorProfilesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
-        [Show boto3-stubs documentation](./client.md#describe-connector-profiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
+        [Show boto3-stubs documentation](./client.md#describe_connector_profiles)
         """
 
     def describe_connectors(
-        self, connectorTypes: List[ConnectorType] = None, nextToken: str = None
+        self, connectorTypes: List[ConnectorTypeType] = None, nextToken: str = None
     ) -> DescribeConnectorsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.describe_connectors)
-        [Show boto3-stubs documentation](./client.md#describe-connectors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.describe_connectors)
+        [Show boto3-stubs documentation](./client.md#describe_connectors)
         """
 
     def describe_flow(self, flowName: str) -> DescribeFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.describe_flow)
-        [Show boto3-stubs documentation](./client.md#describe-flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.describe_flow)
+        [Show boto3-stubs documentation](./client.md#describe_flow)
         """
 
     def describe_flow_execution_records(
         self, flowName: str, maxResults: int = None, nextToken: str = None
     ) -> DescribeFlowExecutionRecordsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
-        [Show boto3-stubs documentation](./client.md#describe-flow-execution-records)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
+        [Show boto3-stubs documentation](./client.md#describe_flow_execution_records)
         """
 
     def generate_presigned_url(
@@ -173,66 +173,66 @@ class AppflowClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def list_connector_entities(
         self,
         connectorProfileName: str = None,
-        connectorType: ConnectorType = None,
+        connectorType: ConnectorTypeType = None,
         entitiesPath: str = None,
     ) -> ListConnectorEntitiesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.list_connector_entities)
-        [Show boto3-stubs documentation](./client.md#list-connector-entities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.list_connector_entities)
+        [Show boto3-stubs documentation](./client.md#list_connector_entities)
         """
 
     def list_flows(self, maxResults: int = None, nextToken: str = None) -> ListFlowsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.list_flows)
-        [Show boto3-stubs documentation](./client.md#list-flows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.list_flows)
+        [Show boto3-stubs documentation](./client.md#list_flows)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def start_flow(self, flowName: str) -> StartFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.start_flow)
-        [Show boto3-stubs documentation](./client.md#start-flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.start_flow)
+        [Show boto3-stubs documentation](./client.md#start_flow)
         """
 
     def stop_flow(self, flowName: str) -> StopFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.stop_flow)
-        [Show boto3-stubs documentation](./client.md#stop-flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.stop_flow)
+        [Show boto3-stubs documentation](./client.md#stop_flow)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_connector_profile(
         self,
         connectorProfileName: str,
-        connectionMode: ConnectionMode,
+        connectionMode: ConnectionModeType,
         connectorProfileConfig: ConnectorProfileConfigTypeDef,
     ) -> UpdateConnectorProfileResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.update_connector_profile)
-        [Show boto3-stubs documentation](./client.md#update-connector-profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.update_connector_profile)
+        [Show boto3-stubs documentation](./client.md#update_connector_profile)
         """
 
     def update_flow(
@@ -245,6 +245,6 @@ class AppflowClient:
         sourceFlowConfig: "SourceFlowConfigTypeDef" = None,
     ) -> UpdateFlowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/appflow.html#Appflow.Client.update_flow)
-        [Show boto3-stubs documentation](./client.md#update-flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/appflow.html#Appflow.Client.update_flow)
+        [Show boto3-stubs documentation](./client.md#update_flow)
         """
